@@ -103,8 +103,10 @@ def process_member_sample(samples) -> dict:
     from collections import defaultdict
     overall_status = defaultdict(int)
 
+    import json
+    import logging
+
     for sample_item in samples:
-        import json
         result = json.loads(sample_item)['data-point']
 
         # we can only work with journal articles
@@ -133,6 +135,8 @@ def process_member_sample(samples) -> dict:
             if has_preservation:
                 overall_status['preserved_count'] += 1
 
+            logging.info('{}: {}'.format(result['DOI'], preservation_statuses))
+
     # add blank keys for archives that weren't used
     for preservation_system, class_o in archives.items():
         if class_o.name() not in overall_status:
@@ -154,7 +158,9 @@ def push_json_to_s3(s3, json_obj, member_id, annotation_bucket, annotation_path,
     :return:
     """
     import json
+    import logging
 
+    logging.info('Writing JSON to S3')
     key = f'{annotation_path}/members/{member_id}/{annotation_filename}'
 
     obj = s3.Object(annotation_bucket, key)
