@@ -74,6 +74,12 @@ class LockssPreservation(models.Model):
     class Meta:
         db_table = "preservationData_locksspreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['eissn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     eissn = models.CharField(max_length=20)
@@ -145,6 +151,12 @@ class CarinianaPreservation(models.Model):
     class Meta:
         db_table = "preservationData_carinianapreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['eissn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     eissn = models.CharField(max_length=20)
@@ -216,6 +228,12 @@ class ClockssPreservation(models.Model):
     class Meta:
         db_table = "preservationData_clocksspreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['eissn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     eissn = models.CharField(max_length=20)
@@ -287,6 +305,11 @@ class PKPPreservation(models.Model):
     class Meta:
         db_table = "preservationData_pkppreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     preserved_volumes = models.TextField()
@@ -357,6 +380,11 @@ class HathiPreservation(models.Model):
     class Meta:
         db_table = "preservationData_hathipreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     preserved_volumes = models.TextField()
@@ -488,6 +516,12 @@ class PorticoPreservation(models.Model):
     class Meta:
         db_table = "preservationData_porticopreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['eissn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
     issn = models.CharField(max_length=20)
     eissn = models.CharField(max_length=20)
@@ -576,6 +610,11 @@ class OculScholarsPortalPreservation(models.Model):
     class Meta:
         db_table = "preservationData_oculpreservation"
 
+        indexes = [
+            models.Index(fields=['issn']),
+            models.Index(fields=['title']),
+        ]
+
     title = models.TextField()
 
     """
